@@ -14,7 +14,7 @@ from gateways.common.cs18_api_errors import UnauthorizedException, MaxRetriesExc
 from gateways.common.cs18_api_requests import (
     CreateInvitationsRequest,
     UpdateSpaceRequest,
-    ProductionEnvironment, DebuggingServiceValue)
+    ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountSettingsRequest)
 from gateways.common.cs18_api_responses import (AccountStatusResponse, BlueprintFileResponse, BlueprintResponse,
                                                 CatalogForGetAllResponse, CatalogForGetResponse, CloudAccountResponse,
                                                 CreateProductionResponse, CreateSandboxResponse, GetSpaceResponse,
@@ -22,7 +22,7 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 ProductionResponseLean, RepositoryResponse, RoleListItemResponse,
                                                 SandboxResponse, SandboxResponseLean, TokenResponse,
                                                 UserInvitationResponse, UserPermittedToSpaceResponse,
-                                                UserForAllUsersResponse)
+                                                UserForAllUsersResponse, CloudAccountInSpaceResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -164,7 +164,8 @@ class Colony:
         method_url = self._api_root.settings.aws_cloud_accounts()
         request = {"arn_role": arn_role, "external_id": external_id}
 
-        print("arn_role " + arn_role)
+        if arn_role is not None:
+            print("arn_role " + arn_role)
 
         if name:
             request["name"] = name
@@ -748,17 +749,38 @@ class Colony:
         res = self.session.delete(url=method_url)
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
-    def add_cloud_account_to_space(self, cloud_account: str):
+    def add_cloud_account_to_space(self, cloud_account: str, settings: SpaceCloudAccountSettingsRequest = None):
         method_url = self._api_root.spaces.space_cloud_accounts(self.space)
-        res = self.session.post(url=method_url, json={"name": cloud_account})
+        data = {"name": cloud_account}
+        if settings:
+            data['internet_facing'] = settings.internet_facing
+            data['virtual_network'] = settings.virtual_network
+            if settings.subnets:
+                data['subnets'] = {'gateway_subnet': settings.subnets.gateway_subnet,
+                                   'management_subnet': settings.subnets.management_subnet,
+                                   'application_subnets': settings.subnets.application_subnets}
+        res = self.session.post(url=method_url, json=data)
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
-    def get_cloud_accounts_under_space(self) -> List[CloudAccountResponse]:
+    def update_cloud_account_in_space(self, cloud_account: str, settings: SpaceCloudAccountSettingsRequest):
+        method_url = self._api_root.spaces.space_cloud_account(space_name=self.space, cloud_account=cloud_account)
+        data = {
+            'internet_facing': settings.internet_facing,
+            'virtual_network': settings.virtual_network
+        }
+        if settings.subnets:
+            data['subnets'] = {'gateway_subnet': settings.subnets.gateway_subnet,
+                               'management_subnet': settings.subnets.management_subnet,
+                               'application_subnets': settings.subnets.application_subnets}
+        res = self.session.put(url=method_url, json=data)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
+    def get_cloud_accounts_under_space(self) -> List[CloudAccountInSpaceResponse]:
         method_url = self._api_root.spaces.space_cloud_accounts(self.space)
         res = self.session.get(url=method_url)
         GatewayUtils.handle_response(response=res, return_codes=[200])
         return [
-            Converters.create_cloud_account_response(x) for x in json.loads(res.text)
+            Converters.create_cloud_account_in_space_response(x) for x in json.loads(res.text)
         ]
 
     def get_account_users(self) -> List[UserForAllUsersResponse]:
@@ -856,8 +878,8 @@ class Colony:
         GatewayUtils.handle_response(response, [200])
         return json.loads(response.text)
 
-    def get_cost_usage(self, date: datetime) -> dict:
-        url = self._api_root.cost.usage(space_name=self.space, date=date)
+    def get_cost_usage(self, date: datetime, timezone: str = '') -> dict:
+        url = self._api_root.cost.usage(space_name=self.space, date=date, timezone=timezone)
         response = self.session.get(url=url)
         GatewayUtils.handle_response(response, [200])
         return json.loads(response.text)
