@@ -41,7 +41,8 @@ from gateways.common.cs18_api_responses import (
     UserForAllUsersResponse,
     ServiceResponse,
     BlueprintServiceResponse,
-    LaunchingProgress, LaunchingProgressStep)
+    LaunchingProgress, LaunchingProgressStep, CloudAccountInSpaceResponse, CloudAccountConnectivityResponse,
+    CloudAccountSubnetsResponse)
 
 
 class Converters:
@@ -228,6 +229,41 @@ class Converters:
             errors=Converters._create_errors(cloud)
         )
 
+    @staticmethod
+    def create_cloud_account_in_space_response(cloud: dict) -> CloudAccountInSpaceResponse:
+        """
+        Returns CloudAccountResponse based on provided dictionary
+        :param cloud: dict
+        :return: CloudAccountResponse
+        """
+        return CloudAccountInSpaceResponse(
+            name=cloud["name"],
+            provider=cloud["type"],
+            created_date=Converters._parse_datetime(cloud.get("created_date")),
+            created_by=cloud["created_by"],
+            internet_facing=cloud["internet_facing"],
+            connectivity=Converters._create_cloud_account_connectivity_response(cloud.get("connectivity")),
+            compute_services=Converters._create_compute_services_response(
+                cloud.get("compute_services", None)
+            ),
+            cost=Converters._create_cloud_account_cost_response(cloud),
+            errors=Converters._create_errors(cloud)
+        )
+
+    @staticmethod
+    def _create_cloud_account_connectivity_response(conn: dict) -> Optional[CloudAccountConnectivityResponse]:
+        if not conn:
+            return None
+
+        return CloudAccountConnectivityResponse(
+            virtual_network=conn.get("virtual_network"),
+            subnets=CloudAccountSubnetsResponse(
+                gateway_subnet=conn["subnets"].get("gateway_subnet"),
+                management_subnet=conn["subnets"].get("management_subnet"),
+                application_subnets=conn["subnets"].get("application_subnets")
+            ) if "subnets" in conn else None
+        )
+
     @staticmethod
     def _create_blueprint_input_response(
             blueprint_input: dict
