@@ -2,6 +2,7 @@
 Container for Request object used in cs18-api-client
 """
 from enum import Enum
+from typing import List
 
 
 class ProductionEnvironment(Enum):
@@ -14,6 +15,25 @@ class DebuggingServiceValue(Enum):
     OFF = 'off'
 
 
+class SpaceCloudAccountSubnetsRequest:
+    def __init__(self, gateway_subnet: str = None,
+                 management_subnet: str = None,
+                 application_subnets: List[str] = None):
+        self.gateway_subnet = gateway_subnet
+        self.management_subnet = management_subnet
+        self.application_subnets = application_subnets
+
+
+class SpaceCloudAccountSettingsRequest:
+    def __init__(self,
+                 internet_facing: bool,
+                 virtual_network: str = None,
+                 subnets: SpaceCloudAccountSubnetsRequest = None):
+        self.internet_facing = internet_facing
+        self.virtual_network = virtual_network
+        self.subnets = subnets
+
+
 class UserSignupRequest:
     def __init__(self, first_name: str, last_name: str, password: str, secret: str):
         self.first_name = first_name
