@@ -698,6 +698,47 @@ class CloudAccountResponse:
         self.errors = errors
 
 
+class CloudAccountSubnetsResponse:
+    def __init__(self, gateway_subnet: str,
+                 management_subnet: str,
+                 application_subnets: List[str]):
+        self.gateway_subnet = gateway_subnet
+        self.management_subnet = management_subnet
+        self.application_subnets = application_subnets
+
+
+class CloudAccountConnectivityResponse:
+    def __init__(self,
+                 virtual_network: str,
+                 subnets: CloudAccountSubnetsResponse):
+        self.virtual_network = virtual_network
+        self.subnets = subnets
+
+
+class CloudAccountInSpaceResponse:
+    def __init__(
+            self,
+            name: str,
+            provider: str,
+            created_date: datetime,
+            created_by: str,
+            internet_facing: bool,
+            connectivity: CloudAccountConnectivityResponse,
+            compute_services: List[CloudComputeService] = None,
+            cost: CloudAccountCostResponse = None,
+            errors: List[Error] = None,
+    ):
+        self.name = name
+        self.provider = provider
+        self.created_date = created_date
+        self.created_by = created_by
+        self.compute_services = compute_services
+        self.cost = cost
+        self.errors = errors
+        self.internet_facing = internet_facing
+        self.connectivity = connectivity
+
+
 class UserInvitationResponse:
     def __init__(
             self,
